@@ -25,8 +25,10 @@
     .factory('horizon.dashboard.container.containers.create.service', createService);
 
   createService.$inject = [
+    '$q',
     'horizon.app.core.openstack-service-api.policy',
     'horizon.app.core.openstack-service-api.zun',
+    'horizon.dashboard.container.containers.adminActions',
     'horizon.dashboard.container.containers.resourceType',
     'horizon.dashboard.container.containers.workflow',
     'horizon.framework.util.actions.action-result.service',
@@ -37,7 +39,7 @@
   ];
 
   function createService(
-    policy, zun, resourceType, workflow,
+    $q, policy, zun, adminActions, resourceType, workflow,
     actionResult, gettext, $qExtensions, modal, toast
   ) {
     var message = {
@@ -66,17 +68,26 @@
     }
 
     function allowed() {
-      return policy.ifAllowed({ rules: [['container', 'add_container']] });
+      var adminAction = true;
+      if (zun.isAdmin()) {
+        adminAction = adminActions.indexOf("create") >= 0;
+      }
+      return $q.all([
+        policy.ifAllowed({ rules: [['container', 'add_container']] }),
+        $qExtensions.booleanAsPromise(adminAction)
+      ]);
     }
 
     function submit(context) {
+      delete context.model.exit_policy;
       if (context.model.restart_policy === "on-failure") {
         if (!context.model.restart_policy_max_retry) {
-          context.model.restart_policy_max_retry = 0;
+          delete context.model.restart_policy_max_retry;
+        } else {
+          context.model.restart_policy =
+            context.model.restart_policy + ":" +
+            context.model.restart_policy_max_retry;
         }
-        context.model.restart_policy =
-          context.model.restart_policy + ":" +
-          context.model.restart_policy_max_retry;
       }
       delete context.model.restart_policy_max_retry;
       context.model.mounts = setMounts(context.model.mounts);
@@ -86,6 +97,9 @@
       delete context.model.networks;
       delete context.model.ports;
       delete context.model.availableNetworks;
+      delete context.model.allocatedNetworks;
+      delete context.model.availableSecurityGroups;
+      delete context.model.allocatedSecurityGroups;
       delete context.model.availablePorts;
       context.model.hints = setSchedulerHints(context.model);
       delete context.model.availableHints;
