@@ -28,6 +28,7 @@
     '$q',
     'horizon.app.core.openstack-service-api.policy',
     'horizon.app.core.openstack-service-api.zun',
+    'horizon.dashboard.container.containers.adminActions',
     'horizon.dashboard.container.containers.resourceType',
     'horizon.dashboard.container.containers.validStates',
     'horizon.dashboard.container.containers.workflow',
@@ -39,11 +40,13 @@
   ];
 
   function updateService(
-    $q, policy, zun, resourceType, validStates, workflow,
+    $q, policy, zun, adminActions, resourceType, validStates, workflow,
     actionResult, gettext, $qExtensions, modal, toast
   ) {
     var message = {
-      success: gettext('Container %s was successfully updated.')
+      success: gettext('Container %s was successfully updated.'),
+      successAttach: gettext('Network %s was successfully attached to container %s.'),
+      successDetach: gettext('Network %s was successfully detached from container %s.')
     };
 
     var service = {
@@ -63,52 +66,18 @@
       var title, submitText;
       title = gettext('Update Container');
       submitText = gettext('Update');
-      var config = workflow.init('update', title, submitText);
-      config.model.id = selected.id;
-
-      // load current data
-      zun.getContainer(selected.id).then(onLoad);
-      function onLoad(response) {
-        config.model.name = response.data.name
-          ? response.data.name : "";
-        config.model.image = response.data.image
-          ? response.data.image : "";
-        config.model.image_driver = response.data.image_driver
-          ? response.data.image_driver : "docker";
-        config.model.image_pull_policy = response.data.image_pull_policy
-          ? response.data.image_pull_policy : "";
-        config.model.command = response.data.command
-          ? response.data.command : "";
-        config.model.hostname = response.data.hostname
-          ? response.data.hostname : "";
-        config.model.cpu = response.data.cpu
-          ? response.data.cpu : "";
-        config.model.memory = response.data.memory
-          ? parseInt(response.data.memory, 10) : "";
-        config.model.restart_policy = response.data.restart_policy.Name
-          ? response.data.restart_policy.Name : "";
-        config.model.restart_policy_max_retry = response.data.restart_policy.MaximumRetryCount
-          ? parseInt(response.data.restart_policy.MaximumRetryCount, 10) : null;
-        config.model.runtime = response.data.runtime
-          ? response.data.runtime : "";
-        config.model.workdir = response.data.workdir
-          ? response.data.workdir : "";
-        config.model.environment = response.data.environment
-          ? hashToString(response.data.environment) : "";
-        config.model.interactive = response.data.interactive
-          ? response.data.interactive : false;
-        config.model.auto_remove = response.data.auto_remove
-          ? response.data.auto_remove : false;
-        config.model.labels = response.data.labels
-          ? hashToString(response.data.labels) : "";
-      }
-
+      var config = workflow.init('update', title, submitText, selected.id);
       return modal.open(config).then(submit);
     }
 
     function allowed(container) {
+      var adminAction = true;
+      if (zun.isAdmin()) {
+        adminAction = adminActions.indexOf("update") >= 0;
+      }
       return $q.all([
         policy.ifAllowed({ rules: [['container', 'edit_container']] }),
+        $qExtensions.booleanAsPromise(adminAction),
         $qExtensions.booleanAsPromise(
           validStates.update.indexOf(container.status) >= 0
         )
@@ -117,8 +86,18 @@
 
     function submit(context) {
       var id = context.model.id;
+      var newNets = [];
+      context.model.networks.forEach(function (newNet) {
+        newNets.push(newNet.id);
+      });
+      changeNetworks(id, context.model.allocatedNetworks, newNets);
+      delete context.model.networks;
+      delete context.model.availableNetworks;
+      delete context.model.allocatedNetworks;
       context.model = cleanUpdateProperties(context.model);
-      return zun.updateContainer(id, context.model).then(success);
+      return $q.all([
+        zun.updateContainer(id, context.model).then(success)
+      ]);
     }
 
     function success(response) {
@@ -134,24 +113,47 @@
       // only "cpu" and "memory" fields are editable.
       for (var key in model) {
         if (model.hasOwnProperty(key) && model[key] === null || model[key] === "" ||
-            (key !== "name" && key !== "cpu" && key !== "memory")) {
+            (key !== "name" && key !== "cpu" && key !== "memory" && key !== "nets")) {
           delete model[key];
         }
       }
       return model;
     }
 
-    function hashToString(hash) {
-      var str = "";
-      for (var key in hash) {
-        if (hash.hasOwnProperty(key)) {
-          if (str.length > 0) {
-            str += ",";
-          }
-          str += key + "=" + hash[key];
+    function changeNetworks(container, oldNets, newNets) {
+      // attach and detach networks
+      var attachedNets = [];
+      var detachedNets = [];
+      newNets.forEach(function(newNet) {
+        if (!oldNets.includes(newNet)) {
+          attachedNets.push(newNet);
         }
-      }
-      return str;
+      });
+      oldNets.forEach(function(oldNet) {
+        if (!newNets.includes(oldNet)) {
+          detachedNets.push(oldNet);
+        }
+      });
+      attachedNets.forEach(function (net) {
+        zun.attachNetwork(container, net).then(successAttach);
+      });
+      detachedNets.forEach(function (net) {
+        zun.detachNetwork(container, net).then(successDetach);
+      });
+    }
+
+    function successAttach(response) {
+      toast.add('success', interpolate(message.successAttach,
+        [response.data.network, response.data.container]));
+      var result = actionResult.getActionResult().updated(resourceType, response.data.container);
+      return result.result;
+    }
+
+    function successDetach(response) {
+      toast.add('success', interpolate(message.successDetach,
+        [response.data.network, response.data.container]));
+      var result = actionResult.getActionResult().updated(resourceType, response.data.container);
+      return result.result;
     }
   }
 })();
